@@ -22,6 +22,12 @@ class ResourceNotFoundError(BaseRedmineError):
         super(ResourceNotFoundError, self).__init__("Requested resource doesn't exist")
 
 
+class ConflictError(BaseRedmineError):
+    """Resource version on the server is newer than client's"""
+    def __init__(self):
+        super(ConflictError, self).__init__("Resource version on the server is newer than client's")
+
+
 class AuthError(BaseRedmineError):
     """Invalid authentication details"""
     def __init__(self):
@@ -79,7 +85,7 @@ class ResourceNoFiltersProvidedError(BaseRedmineError):
 class ResourceNoFieldsProvidedError(BaseRedmineError):
     """No field(s) provided"""
     def __init__(self):
-        super(ResourceNoFieldsProvidedError, self).__init__('Resource needs some fields to be created')
+        super(ResourceNoFieldsProvidedError, self).__init__('Resource needs some fields to be set to be created/updated')
 
 
 class ResourceAttrError(BaseRedmineError):
@@ -88,6 +94,12 @@ class ResourceAttrError(BaseRedmineError):
         super(ResourceAttrError, self).__init__("Resource doesn't have the requested attribute")
 
 
+class ReadonlyAttrError(BaseRedmineError):
+    """Resource can't set attribute that is read only"""
+    def __init__(self):
+        super(ReadonlyAttrError, self).__init__("Can't set read only attribute")
+
+
 class VersionMismatchError(BaseRedmineError):
     """Feature isn't supported on specified Redmine version"""
     def __init__(self, feature):
@@ -98,3 +110,17 @@ class ResourceVersionMismatchError(VersionMismatchError):
     """Resource isn't supported on specified Redmine version"""
     def __init__(self):
         super(ResourceVersionMismatchError, self).__init__('Resource')
+
+
+class ResultSetTotalCountError(BaseRedmineError):
+    """ResultSet hasn't been yet evaluated and cannot yield a total_count"""
+    def __init__(self):
+        super(ResultSetTotalCountError, self).__init__('Total count is unknown before evaluation')
+
+
+class CustomFieldValueError(BaseRedmineError):
+    """Custom fields should be passed as a list of dictionaries"""
+    def __init__(self):
+        super(CustomFieldValueError, self).__init__(
+            "Custom fields should be passed as a list of dictionaries in the form of [{'id': 1, 'value': 'foo'}]"
+        )
